// Chess Paladin problem
// FIU High School Programming Competition, 2015
// Solution by Irvine

// Uses a Breadth-First Search algorithm to explore an implied graph
// of moves based on the knight pattern plus the value of k.

import java.io.File;
import java.util.LinkedList;
import java.util.List;
import java.util.Queue;
import java.util.Scanner;

class Cell {
	int row;
	int col;
	int distance;
	boolean visited;
	
	Cell(int row, int col, int distance) {
		this.row = row;
		this.col = col;
		this.distance = distance;
	}

} // Cell class

public class ChessPaladin {

	final int infinity = 99999;
	Cell[][] board;
	int boardSize;
	int range;
	int startRow;
	int startCol;
	int finishRow;
	int finishCol;
	
	boolean check(int row, int col) {
		if( row > 0 && row <= boardSize && col > 0 && col <= boardSize ) { 
			if( !board[row][col].visited ) {
				return true;
			}
		}
		return false;
	}
		
	List<Cell> getNeighbors(Cell current) 
	{
		List<Cell> list = new LinkedList<>();
		int[] rowOfs = {-2,-2,-1,-1,+1,+1,+2,+2};
		int[] colOfs = {-1,+1,-2,+2,-2,+2,-1,+1};
		
		// get the knight moves first
		for(int i=0; i < 8; i++) {
			int row = current.row + rowOfs[i];
			int col = current.col + colOfs[i];
			if( check(row, col)) 	
				list.add( board[row][col]);
		}  // for
		
		// check the vertical moves
		for(int i = current.row - range; i <= current.row + range; i++)
			if( check(i, current.col) && i != current.row )
				list.add(board[i][current.col]);
		
		// check the horizontal moves
		for(int i = current.col - range; i <= current.col + range; i++)
			if( check(current.row, i) && i != current.col)
				list.add(board[current.row][i]);
		
		return list;
	}
	
	int search()		// breadth-first search algorithm 
	{
		Queue<Cell> queue = new LinkedList<>();
		Cell c = board[startRow][startCol];
		c.visited = true;
		queue.add(c);
		while( !queue.isEmpty() ) {
			Cell current = queue.poll();
			
			//System.out.printf("From queue: cell at %d,%d, d=%d\n", current.row, current.col, current.distance);
			
			if( current.row == finishRow && current.col == finishCol )
				return current.distance;
			
			for( Cell neighbor : getNeighbors(current) ) {
				neighbor.distance = current.distance + 1;
				neighbor.visited = true;
				queue.add(neighbor);
			} // for
		} // while
		return -1;  // not able to find the ending cell!
	}
	
	void start() //throws Exception
	{
		//Scanner in = new Scanner(new File("chesspaladin.judge.in.txt"));
		Scanner in = new Scanner(System.in);
		int numTestCases = in.nextInt();
		for(int t=0; t < numTestCases; t++) {
			boardSize = in.nextInt();	// (N)
			range = in.nextInt();     // horizontal & vertical range (k)
			startRow = in.nextInt();
			startCol = in.nextInt();
			finishRow = in.nextInt();
			finishCol = in.nextInt();
			board = new Cell[boardSize+1][boardSize+1];
			for(int i=1; i <= boardSize; i++)
				for(int j=1; j <= boardSize; j++)
					board[i][j] = new Cell(i,j,0);
			
			System.out.println(search());
		}
	} // start
	
	public static void main(String[] args) //throws Exception
	{
		new ChessPaladin().start();
	}
} // class
